@@ -17,9 +17,10 @@
  *
  */
 
-#include <stdio.h>
 #include <string.h>
+#include <stdio.h>
 #include <stdlib.h>
+#include <iostream.h>
 
 #include "fileutil.h"
 
@@ -71,14 +72,14 @@ read_file(char *progname, char *fileName)
 void
 file_error(char *progname, const char *error, char *file)
 {
-  fprintf (stderr, "%s: %s, file %s\n", progname, error, file);
+  cerr << progname << ": " << error << ", file " << file << endl;
   exit (1);
 }
 
 void
 internal_error(char *progname, const char *error)
 {
-  fprintf (stderr, "%s: Internal error: %s\n", progname, error);
+  cerr << progname << ": Internal error: " << error << endl;
   exit (1);
 }
 
@@ -121,7 +122,8 @@ createOutputFileName( char *inputFileName, char *outputDir )
     }
 
   char *outputFileName = new char[lenght] ;
-  
+  outputFileName[0] = '\0';
+
   if (outputDir)
     {
       strcat (outputFileName, outputDir);
