@@ -157,8 +157,7 @@ print_top( char *progname, char *version, char *docTitle, char *cssUrl,
   generate (VERSION);
   generate( "\nby Lorenzo Bettini, bettini@gnu.org" ) ;
   generate( "\nhttp://w3.newnet.it/bettini" ) ;
-  generate( "\nhttp://www.gnu.org/software/" ) ;
-  generate( PACKAGE ) ;
+  generate( "\nhttp://www.gnu.org/software/src-highlite" ) ;
   generateln( "\">" ) ;
   generate( "<title>" ) ;
   generate( ( docTitle ? docTitle : 
@@ -211,6 +210,12 @@ generate_preproc(const char *s)
   GlobalGenerator->generate_preproc (s);
 }
 
+void
+generate_normal(const char *s)
+{
+  NormalGenerator->generateEntire (s);
+}
+
 void generateNewLine() {
   generateln( "" ) ;
 }
