@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 1999, 2000, Lorenzo Bettini <lorenzo.bettini@penteres.it>
+** Copyright (C) 1999, 2000, 2001 Lorenzo Bettini <bettini@gnu.org>
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 #include "colors.h"
 #include "keys.h"
 
-Tags *GlobalTags = NULL ;
+Tags *GlobalTags = 0 ;
 
 void setTags( Tags *t ) {
   GlobalTags = t ;
