@@ -23,7 +23,8 @@
 
 #include <iostream.h>
 #include <string.h>
-#include <set>
+
+#include "my_set.h"
 
 class Tag
 {
